-- Raid Item Maintainance Dialog


RT_ItemOptions = {
	sortName = function(a, b) return (a.name or "") < (b.name or "") end,
	sortId = function(a, b) return (a.id or 0) < (b.id or 0) end,
}

function RT_ItemOptions:GetItemIid( id )
	if id and type(id)=="string" then
		_,_,id = string.find(id,"(%d+)")
	end
	return id and tonumber(id);
end

function RT_ItemOptions:GetDispName( item, isTitle )
	if not item then return "" end
	local frame = RT_ItemOptionsFrame;
    local L = RaidTracker.L;

	local tag = rawget(frame.items, item.id) and "unsaved" or (not rawget(KARaidTrackerDB.ItemOptions, item.id) and "default")

	if not item.name or not item.quality then
		local name, _, quality = GetItemInfo(item.id);
		if name and not item.name then item.name = name end
		if quality and not item.quality then item.quality = quality end
	end
	if not item.c then
		local color
		if item.quality then
			_, _, _, color = GetItemQualityColor(item.quality);
		end
		if color then item.c = strsub(color,3) end
	end
	local t
	if item.name then
		t = (item.c) and ("|c"..item.c..item.name.."|r") or item.name
	else 
		t = "Unknown (ID: "..item.id..")"
	end
	if tag and (isTitle or tag~="default") then
		t = t .. " ("..L[tag]..")"
	end
	-- ("("..item.id..")  " .. 

	return t, tag;
end


function RT_ItemOptions:OnShow( frame )
    local L = RaidTracker.L;
    
    RT_ItemOptionsFrameHeaderTitle:SetText(L["RaidTracker Item Options"]);
	RT_ItemOptionsFrameHeaderText:SetText("");
	RT_ItemOptionsFrameEditTrackTitle:SetText(L["Track"]..":")
	RT_ItemOptionsFrameEditGroupTitle:SetText(L["Group"]..":")
	RT_ItemOptionsFrameEditCostGetTitle:SetText(L["Get Cost"]..":")
	RT_ItemOptionsFrameEditCostAskTitle:SetText(L["Ask Cost"]..":")
	
	RT_ItemOptions:Update();
end


function RT_ItemOptions:Update( )
	local frame = RT_ItemOptionsFrame
	local options = RaidTracker._options
	frame.itemid = self:GetItemIid(frame.itemid)
	frame.items = frame.items or setmetatable( {}, { __index = KARaidTrackerDB.ItemOptions} );
	
	-- get items, allow for called edit or add through interface
	if frame.itemid and not frame.items[frame.itemid] then
		frame.items[frame.itemid] = { id = frame.itemid, Track = 0, Group = 1, CostGet = 0, CostAsk = 0, }
	end
	frame.list = RaidTracker:TableGetValuesSub(frame.items, self.sortName );
	if frame.itemid then								-- requesting to edit or add a specific one
		for i,v in pairs(frame.list) do
			if v.id == frame.itemid then options.ItemOptionsSelected = i break end
		end
		frame.itemid = nil;
	end
	RT_ItemOptions_ScrollBar_Update()

	local f = RT_ItemOptionsFrameEdit
    if not options.ItemOptionsSelected then
		f:Hide();
		return
	elseif options.ItemOptionsSelected > #frame.list then
		options.ItemOptionsSelected = #frame.list
	end
    local L = RaidTracker.L;
	local item = frame.list[options.ItemOptionsSelected]
	local title, tag = self:GetDispName(item, true);
	f:Hide();
	f.id = options.ItemOptionsSelected
	f.item = item
	RT_ItemOptionsFrameEditTitle:SetText( title );
	RT_ItemOptionsFrameEditLinkID:SetText( "Item ID: " .. item.id );
	RT_ItemOptionsFrameEditTrack:SetValue( item.Track and (item.Track + 1) or 0 ); 
	RT_ItemOptionsFrameEditGroup:SetValue( item.Group and (item.Group + 1) or 0 ); 
	RT_ItemOptionsFrameEditCostGet:SetValue( item.CostGet and (item.CostGet + 1) or 0 ); 
	RT_ItemOptionsFrameEditCostAsk:SetValue( item.CostAsk and (item.CostAsk + 1) or 0 );
	if tag == "default" then
		RT_ItemOptionsFrameEdit_DeleteButton:Disable()
	else
		RT_ItemOptionsFrameEdit_DeleteButton:Enable()		
	end
	f:Show();
end


function RT_ItemOptions:Edit_Save( frame )
	-- propagate default values or add new item to database
	local item = RaidTracker:TableSet(KARaidTrackerDB.ItemOptions, frame.item.id, frame.item, true);
	frame:GetParent().items[item.id] = nil;

	i = RT_ItemOptionsFrameEditTrack:GetValue(); item.Track = (i ~= 0) and i-1 or nil;
	i = RT_ItemOptionsFrameEditGroup:GetValue(); item.Group = (i ~= 0) and i-1 or nil;
	i = RT_ItemOptionsFrameEditCostGet:GetValue(); item.CostGet = (i ~= 0) and i-1 or nil;
	i = RT_ItemOptionsFrameEditCostAsk:GetValue(); item.CostAsk = (i ~= 0) and i-1 or nil;	

	RT_ItemOptions:Update();
end


function RT_ItemOptions:Delete( frame )
	KARaidTrackerDB.ItemOptions[frame.item.id] = nil;	
	frame:GetParent().items[frame.item.id] = nil;	
	RT_ItemOptions:Update();
end


function RT_ItemOptions_ScrollBar_Update( )
	local frame = RT_ItemOptionsFrameListScroll
	local db = KARaidTrackerDB

	local data = RT_ItemOptionsFrame.list
	local maxlines = #data;
	FauxScrollFrame_Update(frame, maxlines, 21, 16);
	for i = 1, 21 do
		local id = i + FauxScrollFrame_GetOffset(frame);
		local sline = "RT_ItemOptionsFrameListScrollLine"..i;
		local line = getglobal(sline);		
		if id > maxlines then
			line:Hide();
	    else
			local item = data[id]
			local title, tag = RT_ItemOptions:GetDispName(item)
	    	line.id = id
	    	line.item = item
	    	line.selected = (db.Options.ItemOptionsSelected == id) and 1 or nil
			line:SetText(title);
			if tag == "unsaved" then
				line:GetFontString():SetTextColor(0.85,0.75,0.10,1);
				line:SetNormalFontObject("GameFontNormal");
			elseif tag == "default" then
				line:GetFontString():SetTextColor(0.85,0.75,0.10,0.58);
				line:SetNormalFontObject("GameFontNormalSmall");
			else
				line:GetFontString():SetTextColor(0.85,0.75,0.10,1);
				line:SetNormalFontObject("GameFontNormal");
			end 
			if line.selected then
				getglobal(sline.."MouseOver"):Show()
				line:SetNormalFontObject("GameFontNormal");
			else
				getglobal(sline.."MouseOver"):Hide()
			end
			line:Show()
		end
	end
	frame:Show()
end


